#!/usr/bin/python

import sys


package_name = "telepathy-glib"
package_dir = "/usr/share/%s-tests" % package_name

non_dbus_tests_env = \
    "G_SLICE=debug-blocks G_DEBUG=fatal_warnings,fatal_criticals " \
    "PYTHONPATH=%s/tools" % (package_dir)
non_dbus_tests = [
    "test-asv",
    "test-availability-cmp",
    "test-capabilities",
    "test-debug-domain",
    "test-dtmf-player",
    "test-enums",
    "test-gnio-util",
    "test-heap",
    "test-internal-debug",
    "test-intset",
    "test-signal-connect-object",
    "test-util",
    "test-util-cxx"
    ]

dbus_tests_env = \
    "XDG_DATA_HOME=%s XDG_DATA_DIRS=%s " \
    "G_SLICE=debug-blocks G_DEBUG=fatal_warnings,fatal_criticals " \
    "sh %s/with-session-bus.sh --config-file=%s/dbus-1/session.conf --" % \
    (package_dir, package_dir, package_dir, package_dir)
dbus_tests = [
    "dbus/test-account",
    "dbus/test-account-channel-request",
    "dbus/test-account-manager",
    "dbus/test-base-client",
    "dbus/test-callable-example",
    "dbus/test-call-cancellation",
    "dbus/test-call-example",
    "dbus/test-channel-dispatcher",
    "dbus/test-channel-dispatch-operation",
    "dbus/test-channel-introspect",
    "dbus/test-channel-request",
    "dbus/test-client",
    "dbus/test-cli-group",
    "dbus/test-cm",
    "dbus/test-connection",
    "dbus/test-connection-bug-18845",
    "dbus/test-connection-error",
    "dbus/test-connection-getinterfaces-failure",
    "dbus/test-connection-handles",
    "dbus/test-connection-inject-bug16307",
    "dbus/test-connection-interests",
    "dbus/test-contact-lists",
    "dbus/test-contacts",
    "dbus/test-contacts-bug-19101",
    "dbus/test-contacts-mixin",
    "dbus/test-contacts-slow-path",
    "dbus/test-dbus",
    "dbus/test-disconnection",
    "dbus/test-error-enum",
    "dbus/test-finalized-in-invalidated-handler",
    "dbus/test-get-interface-after-invalidate",
    "dbus/test-group-mixin",
    "dbus/test-handle-repo",
    "dbus/test-handle-set",
    "dbus/test-invalidated-while-invoking-signals",
    "dbus/test-long-connection-name",
    "dbus/test-message-mixin",
    "dbus/test-params-cm",
    "dbus/test-properties",
    "dbus/test-protocol-objects",
    "dbus/test-self-handle",
    "dbus/test-self-presence",
    "dbus/test-simple-approver",
    "dbus/test-simple-handler",
    "dbus/test-simple-observer",
    "dbus/test-text-mixin",
    "dbus/test-text-respawn",
    "dbus/test-unsupported-interface"
    ]

tests_description = [
    ["non-dbus-unit-tests", "Non D-Bus Unit tests",
     non_dbus_tests_env, non_dbus_tests],
    ["dbus-unit-tests", "D-Bus unit tests",
     dbus_tests_env, dbus_tests]]


def main(args):
    print 'Creating tests.xml file.'

    # open file for output
    output_file = open('tests.xml', 'w')

    # add header information
    output_file.write('<?xml version="1.0" encoding="ISO-8859-1"?>\n')
    output_file.write('<testdefinition version="0.1">\n')
    output_file.write('  <suite name="%s-tests">\n' % package_name)
    output_file.write('\n')

    input_line = 'begin'
    last_input_line = None

    for description in tests_description:
        set_name = description[0]
        set_description = description[1]
        cases_env = description[2]
        cases = description[3]

        output_file.write('    <set name="%s" description="%s" feature="%s">\n' % \
                          (set_name, set_description, package_name))
        output_file.write('\n')

        for case in cases:
            output_file.write('      <case name="%s" level="Component" type="Functional" description="%s">\n' % \
                              (case, case))
            output_file.write('        <step expected_result="0">%s %s/%s</step>\n' % \
                              (cases_env, package_dir, case))
            output_file.write('      </case>\n')

        output_file.write('\n')
        output_file.write('      <environments>\n')
        output_file.write('        <hardware>true</hardware>\n')
        output_file.write('      </environments>\n')
        output_file.write('\n')
        output_file.write('    </set>\n')
        output_file.write('\n')

    output_file.write('  </suite>\n')
    output_file.write('</testdefinition>')
    output_file.close()


if __name__ == '__main__':
    main(sys.argv[1:])
    sys.exit(0)
